LcovNode class

Implementers

Constructors

LcovNode({required String path, int linesFound = 0, int linesHit = 0})
LcovNode.fromJson(Map<String, dynamic> json)

Properties

children → Map<String, LcovNode>
final
hashCode → int
The hash code for this object.
no setterinherited
linesFound ↔ int
getter/setter pair
linesHit ↔ int
getter/setter pair
path → String
final
percent → num
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
simpleReport → String
no setter

Methods

add(LcovNode node) → dynamic
clear() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace({required String newPath}) → LcovNode
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited