LcovRecord class final

Inheritance

Constructors

LcovRecord({required String path, required int linesFound, required int linesHit, required String content, required Map<int, int> lines})
LcovRecord.fromJson(Map<String, dynamic> json)

Properties

children → Map<String, LcovNode>
finalinherited
content → String
final
hashCode → int
The hash code for this object.
no setterinherited
lines → Map<int, int>
final
linesFound ↔ int
getter/setter pairinherited
linesHit ↔ int
getter/setter pairinherited
path → String
finalinherited
percent → num
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
simpleReport → String
no setteroverride

Methods

add(LcovNode node) → dynamic
inherited
clear() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace({required String newPath}) → LcovNode
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited